#[non_exhaustive]pub struct ParseError {
pub display_name: String,
pub source_text: Box<str>,
pub start_line: usize,
pub diagnostic: ParseDiagnostic,
}Expand description
Stable parse error returned by the public library API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringHuman-facing source name, for example a path or <stdin>.
source_text: Box<str>The source text that failed to parse.
start_line: usizeThe 1-based source line number where this parser chunk started.
diagnostic: ParseDiagnosticStructured parser diagnostic.