#[non_exhaustive]pub enum NArgs {
Fixed(usize),
ZeroOrMore,
OneOrMore,
Optional,
AtLeast(usize),
}Expand description
How many arguments a positional slot or keyword takes.
In TOML this can be written as:
- integer
nargs = 1→Fixed(1) "*"→ZeroOrMore"+"→OneOrMore"?"→Optional"N+"e.g."2+"→AtLeast(2)
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fixed(usize)
Exactly n positional arguments. Fixed(0) means a
keyword-only marker (no values of its own).
ZeroOrMore
Zero or more positional arguments — the keyword may appear alone or be followed by any number of values until the next sibling keyword. The default.
OneOrMore
One or more positional arguments. CMake requires at least one value; the splitter force-consumes the first value regardless of token classification so a value that spells a sibling keyword name is still captured.
Optional
Either zero or one positional argument.
AtLeast(usize)
At least n positional arguments; additional values are
consumed until the next sibling keyword.