pub struct PerCommandConfig {
pub command_case: Option<CaseStyle>,
pub keyword_case: Option<CaseStyle>,
pub line_width: Option<usize>,
pub tab_size: Option<usize>,
pub dangle_parens: Option<bool>,
pub dangle_align: Option<DangleAlign>,
pub max_pargs_hwrap: Option<usize>,
pub max_subgroups_hwrap: Option<usize>,
}Expand description
Per-command overrides. All fields are optional — only specified fields override the global config for that command.
Fields
command_case: Option<CaseStyle>Override the command casing rule for this command only.
keyword_case: Option<CaseStyle>Override the keyword casing rule for this command only.
line_width: Option<usize>Override the line width for this command only.
tab_size: Option<usize>Override the indentation width for this command only.
dangle_parens: Option<bool>Override dangling paren placement for this command only.
dangle_align: Option<DangleAlign>Override dangling paren alignment for this command only.
max_pargs_hwrap: Option<usize>Override the hanging-wrap positional argument threshold for this command only.
max_subgroups_hwrap: Option<usize>Override the hanging-wrap subgroup threshold for this command only.