Module error

Module error 

Shared error types used across parsing, config loading, and formatting. Structured error types returned by parsing, config loading, and formatting.

Structs

ConfigError
Stable config-file parse error returned by the public library API.
FileParseError
Structured config/spec deserialization failure metadata used for user-facing diagnostics.
ParseDiagnostic
Crate-owned parser diagnostics used by Error without exposing pest internals in the public API.
ParseError
Stable parse error returned by the public library API.
SpecError
Stable command-spec parse error returned by the public library API.

Enums

Error
Errors that can be returned by parsing, config loading, spec loading, or formatting operations.

Type Aliases

Result
Convenience alias for crate-level results.