Shared error types used across parsing, config loading, and formatting. Structured error types returned by parsing, config loading, and formatting.
Structs
- Config
Error - Stable config-file parse error returned by the public library API.
- File
Parse Error - Structured config/spec deserialization failure metadata used for user-facing diagnostics.
- Parse
Diagnostic - Crate-owned parser diagnostics used by
Errorwithout exposingpestinternals in the public API. - Parse
Error - Stable parse error returned by the public library API.
- Spec
Error - Stable command-spec parse error returned by the public library API.
Enums
- Error
- Errors that can be returned by parsing, config loading, spec loading, or formatting operations.
Type Aliases
- Result
- Convenience alias for crate-level results.